@@ -2,7 +2,7 @@ package lib::restrict;
 
 use strict;
 use warnings;
-our $VERSION = '0.0.4';
+our $VERSION = '0.0.5';
 
 use base 'lib';
 
@@ -29,7 +29,9 @@ sub import {
     
     for (@_) {
 	    my $path = $_; # we'll be modifying it, so break the alias, is there an echo in here :)
-	    $path    = lib::_nativize($path);
+	    eval {
+	        $path    = lib::_nativize($path);
+	    }; # we eval since older lib.pm's don't have this
 	    
 	    if(!-d $path && ref $ENV{'lib::restrict-!-d_ok_in'} eq 'ARRAY') {
 	        my $ok = 0;
@@ -161,4 +163,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
-=cut
\ No newline at end of file
+=cut
